==> jc-1.4.0.tar.gz: soot/jimple/parser/node/X2PMember.h <==
// public final class soot.jimple.parser.node.X2PMember

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 893b8cd202bb6acf soot_jimple_parser_node_X2PMember
// @dep_class 23f44e7eddc0ba3 soot_jimple_parser_node_XPMember

// header file dependencies
// @dep_header soot_jimple_parser_node_XPMember

#include "soot/jimple/parser/node/XPMember.h"

#ifndef _JC_soot_jimple_parser_node_X2PMember_H_
#define _JC_soot_jimple_parser_node_X2PMember_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PMember$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_X2PMember$sub_refs	_jc_soot_jimple_parser_node_X2PMember$sub_refs;
typedef struct _jc_soot_jimple_parser_node_X2PMember$sub_nonrefs	_jc_soot_jimple_parser_node_X2PMember$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_X2PMember$refs	_jc_soot_jimple_parser_node_X2PMember$refs;
typedef struct _jc_soot_jimple_parser_node_X2PMember$nonrefs	_jc_soot_jimple_parser_node_X2PMember$nonrefs;
typedef struct _jc_soot_jimple_parser_node_X2PMember$object	_jc_soot_jimple_parser_node_X2PMember$object;

typedef const struct _jc_soot_jimple_parser_node_X2PMember$vmethods	_jc_soot_jimple_parser_node_X2PMember$vmethods;
typedef const struct _jc_soot_jimple_parser_node_X2PMember$vtable	_jc_soot_jimple_parser_node_X2PMember$vtable;
typedef const struct _jc_soot_jimple_parser_node_X2PMember$vtype	_jc_soot_jimple_parser_node_X2PMember$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_X2PMember$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_X2PMember$object *);
extern void _jc_soot_jimple_parser_node_X2PMember$method$_init$e8302031e1b940ee(_jc_env *, struct _jc_soot_jimple_parser_node_X2PMember$object *, struct _jc_soot_jimple_parser_node_PMember$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_X2PMember$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_X2PMember$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_X2PMember$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_X2PMember$object *);
extern struct _jc_soot_jimple_parser_node_PMember$object *_jc_soot_jimple_parser_node_X2PMember$method$getPMember$89ea892a4f2962b0(_jc_env *, struct _jc_soot_jimple_parser_node_X2PMember$object *);
extern void _jc_soot_jimple_parser_node_X2PMember$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_X2PMember$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_X2PMember$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_X2PMember$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_X2PMember$method$setPMember$a4a9356ac1553b52(_jc_env *, struct _jc_soot_jimple_parser_node_X2PMember$object *, struct _jc_soot_jimple_parser_node_PMember$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_X2PMember$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_X2PMember$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_X2PMember$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_X2PMember$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_X2PMember$method_info$getPMember$89ea892a4f2962b0;
extern _jc_method _jc_soot_jimple_parser_node_X2PMember$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_X2PMember$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_X2PMember$method_info$setPMember$a4a9356ac1553b52;
extern _jc_method _jc_soot_jimple_parser_node_X2PMember$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_X2PMember$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PMember$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PMember$object *);
	struct _jc_soot_jimple_parser_node_PMember$object	*(*getPMember$89ea892a4f2962b0)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PMember$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PMember$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PMember$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setPMember$a4a9356ac1553b52)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PMember$object *, struct _jc_soot_jimple_parser_node_PMember$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PMember$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_X2PMember$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_XPMember$vmethods	soot_jimple_parser_node_XPMember;
	_jc_soot_jimple_parser_node_X2PMember$vmethods	soot_jimple_parser_node_X2PMember;
};

// Vtype
struct _jc_soot_jimple_parser_node_X2PMember$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_X2PMember$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_X2PMember$sub_refs {
	struct _jc_soot_jimple_parser_node_PMember$object	*__5fpMember__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_X2PMember$refs {
    _jc_soot_jimple_parser_node_X2PMember$sub_refs	soot_jimple_parser_node_X2PMember;
    _jc_soot_jimple_parser_node_XPMember$sub_refs	soot_jimple_parser_node_XPMember;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_X2PMember$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_X2PMember$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_XPMember$sub_nonrefs	soot_jimple_parser_node_XPMember;
    _jc_soot_jimple_parser_node_X2PMember$sub_nonrefs	soot_jimple_parser_node_X2PMember;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_X2PMember$object {
	_jc_soot_jimple_parser_node_X2PMember$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_X2PMember$vtype	*vtype;
	_jc_soot_jimple_parser_node_X2PMember$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_X2PMember$vtype _jc_soot_jimple_parser_node_X2PMember$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_X2PMember, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_X2PMember$class_object;

#endif	/* _JC_soot_jimple_parser_node_X2PMember_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/X2PMember.h <==
// public final class soot.jimple.parser.node.X2PMember

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 893b8cd202bb6acf soot_jimple_parser_node_X2PMember
// @dep_class 23f44e7eddc0ba3 soot_jimple_parser_node_XPMember

// header file dependencies
// @dep_header soot_jimple_parser_node_XPMember

#include "soot/jimple/parser/node/XPMember.h"

#ifndef _JC_soot_jimple_parser_node_X2PMember_H_
#define _JC_soot_jimple_parser_node_X2PMember_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PMember$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_X2PMember$sub_refs	_jc_soot_jimple_parser_node_X2PMember$sub_refs;
typedef struct _jc_soot_jimple_parser_node_X2PMember$sub_nonrefs	_jc_soot_jimple_parser_node_X2PMember$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_X2PMember$refs	_jc_soot_jimple_parser_node_X2PMember$refs;
typedef struct _jc_soot_jimple_parser_node_X2PMember$nonrefs	_jc_soot_jimple_parser_node_X2PMember$nonrefs;
typedef struct _jc_soot_jimple_parser_node_X2PMember$object	_jc_soot_jimple_parser_node_X2PMember$object;

typedef const struct _jc_soot_jimple_parser_node_X2PMember$vmethods	_jc_soot_jimple_parser_node_X2PMember$vmethods;
typedef const struct _jc_soot_jimple_parser_node_X2PMember$vtable	_jc_soot_jimple_parser_node_X2PMember$vtable;
typedef const struct _jc_soot_jimple_parser_node_X2PMember$vtype	_jc_soot_jimple_parser_node_X2PMember$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_X2PMember$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_X2PMember$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_X2PMember$method$_init$e8302031e1b940ee(_jc_env *, struct _jc_soot_jimple_parser_node_X2PMember$object *, struct _jc_soot_jimple_parser_node_PMember$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_X2PMember$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_X2PMember$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_X2PMember$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_X2PMember$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_PMember$object *_jc_soot_jimple_parser_node_X2PMember$method$getPMember$89ea892a4f2962b0(_jc_env *, struct _jc_soot_jimple_parser_node_X2PMember$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_X2PMember$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_X2PMember$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_X2PMember$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_X2PMember$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_X2PMember$method$setPMember$a4a9356ac1553b52(_jc_env *, struct _jc_soot_jimple_parser_node_X2PMember$object *, struct _jc_soot_jimple_parser_node_PMember$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_X2PMember$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_X2PMember$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_X2PMember$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_X2PMember$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_X2PMember$method_info$getPMember$89ea892a4f2962b0;
extern _jc_method _jc_soot_jimple_parser_node_X2PMember$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_X2PMember$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_X2PMember$method_info$setPMember$a4a9356ac1553b52;
extern _jc_method _jc_soot_jimple_parser_node_X2PMember$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_X2PMember$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PMember$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PMember$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_PMember$object	*(*getPMember$89ea892a4f2962b0)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PMember$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PMember$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PMember$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setPMember$a4a9356ac1553b52)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PMember$object *, struct _jc_soot_jimple_parser_node_PMember$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PMember$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_X2PMember$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_XPMember$vmethods	soot_jimple_parser_node_XPMember;
	_jc_soot_jimple_parser_node_X2PMember$vmethods	soot_jimple_parser_node_X2PMember;
};

// Vtype
struct _jc_soot_jimple_parser_node_X2PMember$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_X2PMember$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_X2PMember$sub_refs {
	struct _jc_soot_jimple_parser_node_PMember$object	*__5fpMember__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_X2PMember$refs {
    _jc_soot_jimple_parser_node_X2PMember$sub_refs	soot_jimple_parser_node_X2PMember;
    _jc_soot_jimple_parser_node_XPMember$sub_refs	soot_jimple_parser_node_XPMember;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_X2PMember$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_X2PMember$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_XPMember$sub_nonrefs	soot_jimple_parser_node_XPMember;
    _jc_soot_jimple_parser_node_X2PMember$sub_nonrefs	soot_jimple_parser_node_X2PMember;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_X2PMember$object {
	_jc_soot_jimple_parser_node_X2PMember$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_X2PMember$vtype	*vtype;
	_jc_soot_jimple_parser_node_X2PMember$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_X2PMember$vtype _jc_soot_jimple_parser_node_X2PMember$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_X2PMember, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_X2PMember$class_object;

#endif	/* _JC_soot_jimple_parser_node_X2PMember_H_ */
